from django.apps import AppConfig


class EmailConfig(AppConfig):
    name = 'ax3_email'
    verbose_name = 'ax3_email'
